@@ -1,26 +1,37 @@
 import os
 from tempfile import TemporaryDirectory
-from typing import Dict
+from typing import Any, Dict
 
 from agraffe import Agraffe, Service
 
 import click
 
-from fastapi import FastAPI, Request
+from fastapi import Body, FastAPI, Request
 from fastapi.encoders import jsonable_encoder
 
+from . import version
 from .deploy.aws_lambda import AWSLambda
 from .deploy.cloud_functions import CloudFunctions
 from .deploy.models import DeployConfig, DeployPlatform
 from .libs.exceptions import UnsupportedDeployPlatform
+from .libs.logging import get_logger
 from .monitoring.monitor import watch
 
 
 app = FastAPI()
 
+logger = get_logger()
+
 
 @app.get("/monitoring")
-async def monitoring(request: Request) -> Dict[str, str]:
+async def monitoring_with_get(request: Request) -> Dict[str, str]:
+    await watch()
+    return jsonable_encoder({})
+
+
+@app.post("/monitoring")
+async def monitoring_with_post(request: Request, body: Dict[str, Any] = Body(...)) -> Dict[str, str]:
+    logger.info(body)
     await watch()
     return jsonable_encoder({})
 
@@ -71,7 +82,8 @@ def deploy(platform: DeployPlatform,
     if not hasattr(DeployPlatform, platform):
         raise UnsupportedDeployPlatform(platform)
     tmp_dir = TemporaryDirectory(prefix="monitapi")
-    git.Git(tmp_dir.name).clone("https://github.com/fealone/monitapi")
+    repo = git.Repo.clone_from("https://github.com/fealone/monitapi", os.path.join(tmp_dir.name, "monitapi"))
+    repo.git.checkout(version.version)
     shutil.copyfile(file, os.path.join(tmp_dir.name, "monitapi/src/targets.yaml"))
     shutil.copyfile(os.path.join(tmp_dir.name, "monitapi/requirements.txt"),
                     os.path.join(tmp_dir.name, "monitapi/src/requirements.txt"))
